#! python
"""
author: dick mule
purpose: test for batch cash flow load testing and helper functions
"""
import csv
import logging
import sys
import unittest

import pandas as pd

from finx.client import FinXClient, ClientTypes
from finx.helpers.forecast_results import load_results, BatchForecastResults


FIELD_SIZE_LIMIT = sys.maxsize

while True:
    try:
        csv.field_size_limit(FIELD_SIZE_LIMIT)
        break
    except OverflowError:
        FIELD_SIZE_LIMIT = int(FIELD_SIZE_LIMIT / 10)


class BatchCashFlows(unittest.TestCase):
    """Unittest batch cash flows"""

    @property
    # pylint: disable=too-many-lines
    def sample_records(self):
        """
        Return sample records

        :return: all dictionaries for sample data
        :rtype: list[dict]
        """
        return [
            {
                "security_id": "US91911TAQ67",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PFH01",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PFG28",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87264ADM45",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PFF45",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US172967HS33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US22966RAD89",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VDR24",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US828807DJ39",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US828807DK02",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US026874DA29",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US65535HAS85",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US86562MDM91",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92338CAF05",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US0641593U89",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US539830CE70",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US60687YBH18",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US233331BM83",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92344GAX43",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US68902VAJ61",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US875127BJ01",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US875127BH45",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US219350BP93",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PBE16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US13607LWT69",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US03076CAH97",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US219350BQ76",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US694308KR71",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US713448FN30",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PDE97",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US713448FM56",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US45866FAH73",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US45866FAJ30",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00206RDR03",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91159HJB78",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US172967NE72",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US594918CN20",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US756109BT03",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US756109BS20",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US210518CZ72",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US369550AX61",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US06406FAE34",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US927804GA61",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00185AAK07",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US66989HAF55",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US31620MBR60",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US69353RFG83",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US494550AT30",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US26441CAT27",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US26441CAS44",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VCM46",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US88339WAC01",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US74456QCK04",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US26442CAN48",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US136375CV26",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29379VCF85",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US69351UAW36",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29379VCE11",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US24422EXH79",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US24422EXF14",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US89236TLM52",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US744448BZ35",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US53944YAX13",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US89236TLL79",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US53944YAZ60",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US37045XDV55",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US12527GAE35",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US369604BH58",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US12527GAF00",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US606822CY81",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US80282KBJ43",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US694308HL49",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US892331AG44",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US278642AU75",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US036752AZ60",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US927804GQ14",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US06406RAQ02",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US927804GP31",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US202795JN13",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US31620RAK14",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US084664CQ25",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20825UAC80",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US571748BV33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US571748BU59",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US95000U2L65",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US47233WBM01",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US053332BF83",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US053332BE19",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US446150AX20",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US95000U3F88",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00287YAS81",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00287YAR09",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US95000U3E14",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US68233JCF93",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US174610BF15",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29379VBL62",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00774MAG06",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00724PAC32",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US25468PBW59",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29364DAU46",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US06738ECK91",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US637432NV39",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US06738ECJ29",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US89236TLB97",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US172967ML25",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29364WBJ62",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87612EBF25",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87612EBE59",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US30161NAV38",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92940PAG90",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US125523CW86",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US125523CV04",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US172967LJ87",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US125523CU21",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US882508BJ22",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US03740LAC63",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US126117AW05",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US209111GC11",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US693304AY39",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US532457BY33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US075887CS63",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US760759AX86",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US637432NN13",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US55336VBQ23",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US26444HAK77",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US023135BU94",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US15189XAV01",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US023135BT22",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US855244BJ76",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US30040WAK45",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US023135BS49",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US023135BR65",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US03040WAJ45",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US717081EJ89",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US053015AF05",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US02361DAY67",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US03027XBD12",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US882508CE26",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US03027XBC39",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US84265VAE56",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US031162DK36",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US031162DJ62",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US031162DH07",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US855244BG38",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US833034AM32",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US95040QAD60",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20030NDQ16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20030NDP33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20030NDN84",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US37045XER35",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US89236THG31",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US502431AT68",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US281020AM97",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91913YAW03",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US682680AT09",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US682680AS26",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US370334CJ19",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US24703TAG13",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US86765BAK52",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US61747YFL48",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29670GAF90",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US98389BAV27",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US931142EB57",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US26443TAB26",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US931142EE96",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US38141GYB49",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US89352HAL33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US931142EC31",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87264ADN28",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US10112RAY09",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US15189XAQ16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92936UAG40",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US57636QAQ73",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US548661DW49",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US548661DV65",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US57636QAP90",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US713448DD75",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US404280CK33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20030NDH17",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US57636QAR56",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US174610AK19",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20030NDG34",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US20030NDK46",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87264ABS33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50249AAK97",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50249AAJ25",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87264ABT16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50249AAH68",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US718547AX08",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50077LAV80",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PBU57",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US80282KBH86",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50249AAG85",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US94973VAH06",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50249AAF03",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US031162DS61",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US031162DR88",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US031162DQ06",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US49456BAZ40",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US10112RBC79",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US745332CJ30",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US863667AG64",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US776743AG17",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US961214FR90",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US606822CT96",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US059165ER77",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US278062AE43",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US548661AK38",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87264ACQ67",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US694308KG17",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92277GAM96",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US694308KF34",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US45687AAP75",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US45687AAN28",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US927804GF58",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US701094AS32",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US701094AR58",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US747525BR34",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US747525BQ50",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US67103HAL15",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29379VBJ17",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29379VBH50",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US14040HCT05",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11271LAD47",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US14040HCS22",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US594918BS26",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US456873AE85",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US655844BY34",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US437076BF88",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US172967BL44",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US65473QBD43",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VFV18",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VFU35",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US976843BJ00",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US06738ECR45",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US718172CW74",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VFT61",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US87264ADD46",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US67021CAJ62",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US110122EF17",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US036752AK91",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US404280DQ93",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VFR06",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00206RDT68",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92343VFS88",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US06051GHT94",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US26442UAG94",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92826CAN20",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US404280AQ21",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29444UBQ85",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US92277GAN79",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US842434CR16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US454889AT36",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US67077MAX65",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US58013MEN02",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US24422EVF32",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US502431AS85",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US639057AG33",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US0778FPAF64",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US842400HS51",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US842400FC28",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US907818FK90",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US91324PFJ66",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US574599BP01",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US78016EZT71",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US50249AAM53",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US842400JF13",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US404280DS59",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US49326EEK55",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US446150BC73",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US65473QAX16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US67103HAK32",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FAQ46",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FBB67",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US67077MBB37",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FAN15",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US694308KQ98",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FAL58",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FBA84",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US95709TAJ97",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29717PAX50",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29717PAW77",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US594918BR43",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US718172DE67",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US084423AT91",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US29250NBA28",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US14149YAW84",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US49446RAX70",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US78409VAR50",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US907818FH61",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US78409VAS34",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US00108WAR16",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US278865BG49",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US502431AF64",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US278865BF65",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FBK66",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US11135FCC32",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US49456BAU52",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US36267VAH69",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
            {
                "security_id": "US78016EYH43",
                "as_of_date": "9/30/24",
                "principal_amount": 100,
                "market_value": 100,
            },
        ]

    def test_batch_forecast(self):
        """
        Function should return all api functions from endpoint

        :return: None type
        :rtype: None
        """
        logging.getLogger().setLevel(logging.INFO)
        finx_client = FinXClient(ClientTypes.socket)
        finx_client.load_functions()
        data = pd.DataFrame(self.sample_records)
        data["skip_projections"] = True
        payload = {}
        for column in data.columns:
            payload[column] = data[column].tolist()
        results = finx_client.batch_forecast_cf_and_prices(payload)
        unpacked_results: list[BatchForecastResults] = list(map(load_results, results))
        n_errors = sum(x.error is not None for x in unpacked_results)
        logging.info(
            "Errors: %i / Success: %d", n_errors, len(unpacked_results) - n_errors
        )
        self.assertTrue(isinstance(unpacked_results[0], BatchForecastResults))
        self.assertEqual(n_errors, 0)
        finx_client.cleanup()


if __name__ == "__main__":
    unittest.main()
